@@ -1,11 +1,11 @@
 import requests
-from bolinette.utils import logger
 
 from bolinette import blnt
 
 
 class Mailgun:
     def __init__(self, context: 'blnt.BolinetteContext'):
+        self.context = context
         self.url = context.env['mailgun_url']
         self.ready = True
         self.key = context.env['mailgun_api']
@@ -15,13 +15,13 @@ class Mailgun:
     def _validate_attrs(self):
         if not self.url:
             self.ready = False
-            logger.error('MAILGUN_URL env key not set')
+            self.context.logger.error('MAILGUN_URL env key not set')
         if not self.key:
             self.ready = False
-            logger.error('MAILGUN_API env key not set')
+            self.context.logger.error('MAILGUN_API env key not set')
         if not self.from_adr:
             self.ready = False
-            logger.error('MAILGUN_FROM env key not set')
+            self.context.logger.error('MAILGUN_FROM env key not set')
 
     def send(self, to, subject, content):
         if self.ready:
